Traceability Matrix
===================

Matrix generation and format rendering.

Generator
---------

.. module:: jamb.matrix.generator

.. autofunction:: generate_matrix

HTML Format
-----------

.. module:: jamb.matrix.formats.html

.. autofunction:: render_html

Markdown Format
---------------

.. module:: jamb.matrix.formats.markdown

.. autofunction:: render_markdown

JSON Format
-----------

.. module:: jamb.matrix.formats.json

.. autofunction:: render_json

CSV Format
----------

.. module:: jamb.matrix.formats.csv

.. autofunction:: render_csv

XLSX Format
-----------

.. module:: jamb.matrix.formats.xlsx

.. autofunction:: render_xlsx
